==> jc-1.4.0.tar.gz: gnu/java/awt/EmbeddedWindow.h <==
// public class gnu.java.awt.EmbeddedWindow

// class file dependencies
// @dep_class 5cc37e9e6cd05cb gnu_java_awt_EmbeddedWindow
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class c14a2362b2109d4 java_awt_Frame
// @dep_class 184d12f43c3697c9 java_awt_Window
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_Frame

#include "java/awt/Frame.h"

#ifndef _JC_gnu_java_awt_EmbeddedWindow_H_
#define _JC_gnu_java_awt_EmbeddedWindow_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_awt_EmbeddedWindow$sub_refs	_jc_gnu_java_awt_EmbeddedWindow$sub_refs;
typedef struct _jc_gnu_java_awt_EmbeddedWindow$sub_nonrefs	_jc_gnu_java_awt_EmbeddedWindow$sub_nonrefs;
typedef struct _jc_gnu_java_awt_EmbeddedWindow$refs	_jc_gnu_java_awt_EmbeddedWindow$refs;
typedef struct _jc_gnu_java_awt_EmbeddedWindow$nonrefs	_jc_gnu_java_awt_EmbeddedWindow$nonrefs;
typedef struct _jc_gnu_java_awt_EmbeddedWindow$object	_jc_gnu_java_awt_EmbeddedWindow$object;

typedef struct _jc_gnu_java_awt_EmbeddedWindow$fields_struct	_jc_gnu_java_awt_EmbeddedWindow$fields_struct;
typedef const struct _jc_gnu_java_awt_EmbeddedWindow$vmethods	_jc_gnu_java_awt_EmbeddedWindow$vmethods;
typedef const struct _jc_gnu_java_awt_EmbeddedWindow$vtable	_jc_gnu_java_awt_EmbeddedWindow$vtable;
typedef const struct _jc_gnu_java_awt_EmbeddedWindow$vtype	_jc_gnu_java_awt_EmbeddedWindow$vtype;

// Class fields structure
struct _jc_gnu_java_awt_EmbeddedWindow$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24awt__24Component;
};
extern _jc_gnu_java_awt_EmbeddedWindow$fields_struct _jc_gnu_java_awt_EmbeddedWindow$class_fields;

// Constructors
extern void _jc_gnu_java_awt_EmbeddedWindow$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_EmbeddedWindow$object *);
extern void _jc_gnu_java_awt_EmbeddedWindow$method$_init$8de6a0a3bec04d2a(_jc_env *, struct _jc_gnu_java_awt_EmbeddedWindow$object *, jlong);

// Virtual methods
extern void _jc_gnu_java_awt_EmbeddedWindow$method$addNotify$ce98320b2caf56cf(_jc_env *, struct _jc_gnu_java_awt_EmbeddedWindow$object *);
extern jlong _jc_gnu_java_awt_EmbeddedWindow$method$getHandle$15e78a66c228ddf9(_jc_env *, struct _jc_gnu_java_awt_EmbeddedWindow$object *);
extern void _jc_gnu_java_awt_EmbeddedWindow$method$setHandle$dc0ea459e4a64a59(_jc_env *, struct _jc_gnu_java_awt_EmbeddedWindow$object *, jlong);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_EmbeddedWindow$method_info$addNotify$ce98320b2caf56cf;
extern _jc_method _jc_gnu_java_awt_EmbeddedWindow$method_info$getHandle$15e78a66c228ddf9;
extern _jc_method _jc_gnu_java_awt_EmbeddedWindow$method_info$setHandle$dc0ea459e4a64a59;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_awt_EmbeddedWindow$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_awt_EmbeddedWindow$vmethods {
	void	(*addNotify$ce98320b2caf56cf)(_jc_env *, struct _jc_gnu_java_awt_EmbeddedWindow$object *);
	jlong	(*getHandle$15e78a66c228ddf9)(_jc_env *, struct _jc_gnu_java_awt_EmbeddedWindow$object *);
	void	(*setHandle$dc0ea459e4a64a59)(_jc_env *, struct _jc_gnu_java_awt_EmbeddedWindow$object *, jlong);
};

// Vtable
struct _jc_gnu_java_awt_EmbeddedWindow$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_java_awt_Window$vmethods	java_awt_Window;
	_jc_java_awt_Frame$vmethods	java_awt_Frame;
	_jc_gnu_java_awt_EmbeddedWindow$vmethods	gnu_java_awt_EmbeddedWindow;
};

// Vtype
struct _jc_gnu_java_awt_EmbeddedWindow$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_EmbeddedWindow$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_EmbeddedWindow$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_EmbeddedWindow$refs {
    _jc_gnu_java_awt_EmbeddedWindow$sub_refs	gnu_java_awt_EmbeddedWindow;
    _jc_java_awt_Frame$sub_refs	java_awt_Frame;
    _jc_java_awt_Window$sub_refs	java_awt_Window;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_EmbeddedWindow$sub_nonrefs {
	jlong	handle;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_EmbeddedWindow$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_java_awt_Window$sub_nonrefs	java_awt_Window;
    _jc_java_awt_Frame$sub_nonrefs	java_awt_Frame;
    _jc_gnu_java_awt_EmbeddedWindow$sub_nonrefs	gnu_java_awt_EmbeddedWindow;
};

// Object instance structure
struct _jc_gnu_java_awt_EmbeddedWindow$object {
	_jc_gnu_java_awt_EmbeddedWindow$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_EmbeddedWindow$vtype	*vtype;
	_jc_gnu_java_awt_EmbeddedWindow$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_EmbeddedWindow$vtype _jc_gnu_java_awt_EmbeddedWindow$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_EmbeddedWindow, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_EmbeddedWindow$class_object;

#endif	/* _JC_gnu_java_awt_EmbeddedWindow_H_ */

==> jc-1.4.5.tar.gz: gnu/java/awt/EmbeddedWindow.h <==
// public class gnu.java.awt.EmbeddedWindow

// class file dependencies
// @dep_class 5cc37e9e6cd05cb gnu_java_awt_EmbeddedWindow
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class f9fc65873f556df3 java_awt_Frame
// @dep_class fd4ae025aa56ceb9 java_awt_Window
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_Frame

#include "java/awt/Frame.h"

#ifndef _JC_gnu_java_awt_EmbeddedWindow_H_
#define _JC_gnu_java_awt_EmbeddedWindow_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_java_awt_EmbeddedWindow$sub_refs	_jc_gnu_java_awt_EmbeddedWindow$sub_refs;
typedef struct _jc_gnu_java_awt_EmbeddedWindow$sub_nonrefs	_jc_gnu_java_awt_EmbeddedWindow$sub_nonrefs;
typedef struct _jc_gnu_java_awt_EmbeddedWindow$refs	_jc_gnu_java_awt_EmbeddedWindow$refs;
typedef struct _jc_gnu_java_awt_EmbeddedWindow$nonrefs	_jc_gnu_java_awt_EmbeddedWindow$nonrefs;
typedef struct _jc_gnu_java_awt_EmbeddedWindow$object	_jc_gnu_java_awt_EmbeddedWindow$object;

typedef struct _jc_gnu_java_awt_EmbeddedWindow$fields_struct	_jc_gnu_java_awt_EmbeddedWindow$fields_struct;
typedef const struct _jc_gnu_java_awt_EmbeddedWindow$vmethods	_jc_gnu_java_awt_EmbeddedWindow$vmethods;
typedef const struct _jc_gnu_java_awt_EmbeddedWindow$vtable	_jc_gnu_java_awt_EmbeddedWindow$vtable;
typedef const struct _jc_gnu_java_awt_EmbeddedWindow$vtype	_jc_gnu_java_awt_EmbeddedWindow$vtype;

// Class fields structure
struct _jc_gnu_java_awt_EmbeddedWindow$fields_struct {
	struct _jc_java_lang_Class$object	*class__24java__24awt__24Component;
};
extern _jc_gnu_java_awt_EmbeddedWindow$fields_struct _jc_gnu_java_awt_EmbeddedWindow$class_fields;

// Constructors
extern void _jc_gnu_java_awt_EmbeddedWindow$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_EmbeddedWindow$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_EmbeddedWindow$method$_init$8de6a0a3bec04d2a(_jc_env *, struct _jc_gnu_java_awt_EmbeddedWindow$object *, jlong) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_EmbeddedWindow$method$addNotify$ce98320b2caf56cf(_jc_env *, struct _jc_gnu_java_awt_EmbeddedWindow$object *) _JC_JCNI_ATTR;
extern jlong _jc_gnu_java_awt_EmbeddedWindow$method$getHandle$15e78a66c228ddf9(_jc_env *, struct _jc_gnu_java_awt_EmbeddedWindow$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_EmbeddedWindow$method$setHandle$dc0ea459e4a64a59(_jc_env *, struct _jc_gnu_java_awt_EmbeddedWindow$object *, jlong) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_EmbeddedWindow$method_info$addNotify$ce98320b2caf56cf;
extern _jc_method _jc_gnu_java_awt_EmbeddedWindow$method_info$getHandle$15e78a66c228ddf9;
extern _jc_method _jc_gnu_java_awt_EmbeddedWindow$method_info$setHandle$dc0ea459e4a64a59;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_awt_EmbeddedWindow$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_awt_EmbeddedWindow$vmethods {
	void	(*addNotify$ce98320b2caf56cf)(_jc_env *, struct _jc_gnu_java_awt_EmbeddedWindow$object *) _JC_JCNI_ATTR;
	jlong	(*getHandle$15e78a66c228ddf9)(_jc_env *, struct _jc_gnu_java_awt_EmbeddedWindow$object *) _JC_JCNI_ATTR;
	void	(*setHandle$dc0ea459e4a64a59)(_jc_env *, struct _jc_gnu_java_awt_EmbeddedWindow$object *, jlong) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_EmbeddedWindow$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_java_awt_Window$vmethods	java_awt_Window;
	_jc_java_awt_Frame$vmethods	java_awt_Frame;
	_jc_gnu_java_awt_EmbeddedWindow$vmethods	gnu_java_awt_EmbeddedWindow;
};

// Vtype
struct _jc_gnu_java_awt_EmbeddedWindow$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_EmbeddedWindow$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_EmbeddedWindow$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_EmbeddedWindow$refs {
    _jc_gnu_java_awt_EmbeddedWindow$sub_refs	gnu_java_awt_EmbeddedWindow;
    _jc_java_awt_Frame$sub_refs	java_awt_Frame;
    _jc_java_awt_Window$sub_refs	java_awt_Window;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_EmbeddedWindow$sub_nonrefs {
	jlong	handle;
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_EmbeddedWindow$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_java_awt_Window$sub_nonrefs	java_awt_Window;
    _jc_java_awt_Frame$sub_nonrefs	java_awt_Frame;
    _jc_gnu_java_awt_EmbeddedWindow$sub_nonrefs	gnu_java_awt_EmbeddedWindow;
};

// Object instance structure
struct _jc_gnu_java_awt_EmbeddedWindow$object {
	_jc_gnu_java_awt_EmbeddedWindow$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_EmbeddedWindow$vtype	*vtype;
	_jc_gnu_java_awt_EmbeddedWindow$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_EmbeddedWindow$vtype _jc_gnu_java_awt_EmbeddedWindow$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_EmbeddedWindow, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_EmbeddedWindow$class_object;

#endif	/* _JC_gnu_java_awt_EmbeddedWindow_H_ */
